﻿define([
    'kendo',
    'views/layout/layout',
    'views/menu/menu',
    'viewloader',
    'sidebarloader',
    'views/makerequest/makerequest',
    'views/makerequest/folderaccess/folderaccess',
    'views/makerequest/softwareaccess/softwareaccess',
    'views/makerequest/equipmentloan/equipmentloan',
    'views/makerequest/equipmentacquisition/equipmentacquisition',
    'views/approverequest/folderaccess/folderaccess',
    'views/approverequest/softwareaccess/softwareaccess'
], function (kendo,
             layout,
             menu,
             viewloader,
             sidebarloader,
             makerequest,
             mrfolderaccess,
             mrsoftwareaccess,
             equipmentloan,
             equipmentacquisition,
             arfolderaccess,
             arsoftwareaccess)
{
    // the application router
    var router = new kendo.Router({
        init: function ()
        {
            setupRoutes();
            // render the layout and menu first            
            layout.render("#applicationHost");
            menu.menu.render("#appMenu");
        },
        routeMissing: function (e)
        {
            e.preventDefault();

            // debug shim writes console errors to the browser dev tools
            //debug.error('No Route Found', e.url);
        },

        change: function (e)
        {
            if (!isAuthorisedToNavigateToPage(e.url))
            {
                require(['views/unauthorised/unauthorised'], function (unauthorised)
                {
                    viewloader.loadView(unauthorised);
                });
            }
            else
            {
                var rooturl = e.url.split("?")[0].split("#")[0];
                var menuItem = rooturl.split("/")[1];
                var sideMenuItem = rooturl.split("/")[2];

                // publish an event whenever the route changes
                $.publish('/router/change', [e]);

                if (e.url == "/" || (e.params && e.params.menu == 'true'))
                {
                    // publish an event whenever the menu changes
                    $.publish('/menu/change', [e]);

                    if (menuItem != $("#CurrentMenu").val())
                    {
                        $("#CurrentMenu").val(menuItem);

                        try
                        {
                            sidebarloader.loadSidebar(e.url);
                        }
                        catch (ex)
                        { }
                    }
                }
                else
                {
                    // publish an event whenever the submenu changes
                    $.publish('/sidemenu/change', [e]);

                    if (sideMenuItem != $("#CurrentSideMenu").val())
                    {
                        $("#CurrentSideMenu").val(sideMenuItem);
                    }
                }

                //load if refresh (both values will be empty)
                if (!$("#CurrentMenu").val() && $("#CurrentSideMenu").val())
                {
                    menu.setActiveMenuState(e.url);

                    try
                    {
                        sidebarloader.loadSidebar(e.url);
                    }
                    catch (ex)
                    { }
                }

                NavigateToPage(e.url, e.params);
            }
        }
    });
    function setupRoutes()
    {
        router.route("/", function (e)
        { //Go to default start page.
            router.navigate("#/makerequest?menu=true");
        });
        router.route("/makerequest/folderaccess(/:id)", function (id) { });
        router.route("/makerequest/softwareaccess(/:id)", function (id) { });
        router.route("/makerequest/equipmentloan(/:id)", function (id) { });
        router.route("/makerequest/equipmentacquisition(/:id)", function (id) { });
        router.route("/makerequest(/:menu)", function (menu) { });
        router.route("/approverequest/folderaccess(/:id)", function (id) { });
        router.route("/approverequest/softwareaccess(/:id)", function (id) { });
        router.route("/approverequest(/:menu)", function (menu) { });

    }

    function isAuthorisedToNavigateToPage(url)
    {
        var isAuthorised = false;

        if ($("#CurrentUserIsAdmin").val() == "True" || (url.indexOf("/manage") != 0 && url.indexOf("/audit") != 0 && url.indexOf("/admin") != 0))
        {
            isAuthorised = true;
        }
        else
        {
            if ($("#CurrentUserIsAuditor").val() == "True" && url.indexOf("/audit") == 0)
            {
                isAuthorised = true;
            }
            else if ($("#CurrentUserIsSystemManager").val() == "True" && url.indexOf("/manage") == 0)
            {
                isAuthorised = true;
            }
        }

        return isAuthorised;
    }

    function NavigateToPage(url, params)
    {
        if (url)
        {
            var rooturl = url.split("?")[0].split("#")[0];

            var id = 0;

            if (params)
            {
                if (params.id)
                {
                    id = params.id;
                }
            }

            switch (rooturl)
            {
                case "/makerequest":  //Default to folder access for makerequest root menu
                    viewloader.loadView(mrfolderaccess);
                    break;
                case "/makerequest/folderaccess":
                    viewloader.loadView(mrfolderaccess);
                    break;
                case "/makerequest/softwareaccess":
                    viewloader.loadView(mrsoftwareaccess);
                    break;
                case "/makerequest/equipmentloan":
                    viewloader.loadView(equipmentloan(id));
                    break;
                case "/makerequest/equipmentacquisition":
                    viewloader.loadView(equipmentacquisition);
                    break;
                case "/approverequest":  //Default to folder access for approverequest root menu
                    viewloader.loadView(arfolderaccess);
                    break;
                case "/approverequest/folderaccess":
                    viewloader.loadView(arfolderaccess);
                    break;
                case "/approverequest/softwareaccess":
                    viewloader.loadView(arsoftwareaccess);
                    break;
                default:  //Default to makerequest folder access
                    viewloader.loadView(mrfolderaccess);
                    break;
            }
        }
    }

    return router;
});