﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Web;
using System.Web.Mvc;


public enum TopMenu
{
    MakeRequest = 0,
    ApproveRequest = 1,
    Audit = 2,
    Admin = 3,
    About = 4
}

public static class HtmlHelperExtensions
{
    public static string ActiveMenu(this HtmlHelper html, TopMenu menu, string activeClassName, TopMenu current)
    {
        string result = null;

        if(menu == current)
        {
            result = string.Format(" {0} ", activeClassName);
        }

        return result;
    }

    public static string ActiveMenu(this HtmlHelper html, string menuName, string activeClassName, string currentMenuName)
    {
        string result = null;

        if(!string.IsNullOrEmpty(menuName) && !string.IsNullOrEmpty(currentMenuName))
        {
            if(menuName == currentMenuName)
            {
                result = string.Format("class={0} ", activeClassName);
            }
        }

        return result;
    }

    private const string _jSViewDataName = "RenderJavaScript";
    private const string _styleViewDataName = "RenderStyle";

    public static void AddJavaScript(this HtmlHelper htmlHelper, string scriptURL)
    {
        List<string> scriptList = htmlHelper.ViewContext.HttpContext.Items[HtmlHelperExtensions._jSViewDataName] as List<string>;
        if(scriptList != null)
        {
            if(!scriptList.Contains(scriptURL))
            {
                scriptList.Add(scriptURL);
            }
        }
        else
        {
            scriptList = new List<string>();
            scriptList.Add(scriptURL);
            htmlHelper.ViewContext.HttpContext.Items.Add(HtmlHelperExtensions._jSViewDataName, scriptList);
        }
    }

    public static MvcHtmlString RenderJavaScripts(this HtmlHelper HtmlHelper)
    {
        StringBuilder result = new StringBuilder();

        List<string> scriptList = HtmlHelper.ViewContext.HttpContext
          .Items[HtmlHelperExtensions._jSViewDataName] as List<string>;
        if(scriptList != null)
        {
            foreach(string script in scriptList)
            {
                result.AppendLine(string.Format("<script type=\"text/javascript\" src=\"{0}\"></script>", script));
            }
        }

        return MvcHtmlString.Create(result.ToString());
    }

    public static void AddStyle(this HtmlHelper htmlHelper, string styleURL)
    {
        List<string> styleList = htmlHelper.ViewContext.HttpContext.Items[HtmlHelperExtensions._styleViewDataName] as List<string>;

        if(styleList != null)
        {
            if(!styleList.Contains(styleURL))
            {
                styleList.Add(styleURL);
            }
        }
        else
        {
            styleList = new List<string>();
            styleList.Add(styleURL);
            htmlHelper.ViewContext.HttpContext.Items.Add(HtmlHelperExtensions._styleViewDataName, styleList);
        }
    }

    public static MvcHtmlString RenderStyles(this HtmlHelper htmlHelper)
    {
        StringBuilder result = new StringBuilder();

        List<string> styleList = htmlHelper.ViewContext.HttpContext.Items[HtmlHelperExtensions._styleViewDataName] as List<string>;

        if(styleList != null)
        {
            foreach(string script in styleList)
            {
                result.AppendLine(string.Format("<link href=\"{0}\" rel=\"stylesheet\" type=\"text/css\" />", script));
            }
        }

        return MvcHtmlString.Create(result.ToString());
    }


}
